# vim: set fileencoding=utf-8 :
###############################################################################
#                                                                             #
# Copyright (c) 2019 Idiap Research Institute, http://www.idiap.ch/           #
# Contact: beat.support@idiap.ch                                              #
#                                                                             #
# This file is part of the beat.editor module of the BEAT platform.           #
#                                                                             #
# Commercial License Usage                                                    #
# Licensees holding valid commercial BEAT licenses may use this file in       #
# accordance with the terms contained in a written agreement between you      #
# and Idiap. For further information contact tto@idiap.ch                     #
#                                                                             #
# Alternatively, this file may be used under the terms of the GNU Affero      #
# Public License version 3 as published by the Free Software and appearing    #
# in the file LICENSE.AGPL included in the packaging of this file.            #
# The BEAT platform is distributed in the hope that it will be useful, but    #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  #
# or FITNESS FOR A PARTICULAR PURPOSE.                                        #
#                                                                             #
# You should have received a copy of the GNU Affero Public License along      #
# with the BEAT platform. If not, see http://www.gnu.org/licenses/.           #
#                                                                             #
###############################################################################

from PyQt5.QtWidgets import QHBoxLayout
from PyQt5.QtWidgets import QMainWindow
from PyQt5.QtWidgets import QWidget
from PyQt5.QtWidgets import qApp

from .assetbrowser import AssetBrowser
from .assetwidget import AssetWidget


class MainWindow(QMainWindow):
    """
    Main window of the beat.editor application
    """

    def __init__(self, parent=None):
        """Constructor"""

        super(MainWindow, self).__init__(parent)

        menubar = self.menuBar()
        fileMenu = menubar.addMenu(self.tr("File"))
        quitAction = fileMenu.addAction(self.tr("Quit"))
        quitAction.setShortcut("CTRL+Q")
        quitAction.triggered.connect(qApp.quit)

        preferencesMenu = menubar.addMenu(self.tr("Preferences"))
        settingsAction = preferencesMenu.addAction(self.tr("Settings"))

        self.assetBrowser = AssetBrowser()
        self.assetWidget = AssetWidget()

        centralWidget = QWidget()
        layout = QHBoxLayout(centralWidget)
        layout.addWidget(self.assetBrowser)
        layout.addWidget(self.assetWidget)
        self.setCentralWidget(centralWidget)

        self.assetBrowser.json_selected.connect(self.assetWidget.show_json)
        settingsAction.triggered.connect(self.show_settings)

    def set_prefix_root(self, prefix_root_path):
        """Sets the root path of the prefix to edit"""

        self.assetBrowser.set_prefix_root(prefix_root_path)

    def show_settings(self):
        """Show settings dialog"""
        pass
